@@ -4,15 +4,16 @@ test_that("ObjectiveFSelect", {
   resampling = rsmp("holdout")
   measures = msr("dummy")
 
-  obj = ObjectiveFSelect$new(task = task, learner = learner,
-    resampling = resampling, measures = measures, store_models = TRUE)
+  archive = ArchiveFSelect$new(search_space = task_to_domain(task), codomain = measures_to_codomain(measures))
+
+  obj = ObjectiveFSelect$new(task = task, learner = learner, resampling = resampling, measures = measures, archive = archive, store_models = TRUE)
 
   xss = list(
     list("x1" = TRUE, "x2" = FALSE, "x3" = TRUE, "x4" = TRUE),
     list("x1" = FALSE, "x2" = TRUE, "x3" = TRUE, "x4" = TRUE))
 
   z = obj$eval_many(xss)
-  expect_data_table(z, nrows = 2, ncols = 3)
+  expect_data_table(z, nrows = 2, ncols = 5)
   expect_equal(obj$archive$benchmark_result$resample_result(1)$learners[[1]]$model$select$selection, c("x1", "x3", "x4"))
   expect_equal(obj$archive$benchmark_result$resample_result(2)$learners[[1]]$model$select$selection, c("x2", "x3", "x4"))
 })
@@ -23,15 +24,15 @@ test_that("ObjectiveFSelect works with multiple measures", {
   resampling = rsmp("holdout")
   measures = msrs(c("regr.mse", "regr.rmse"))
 
-  obj = ObjectiveFSelect$new(task = task, learner = learner,
-    resampling = resampling, measures = measures, store_models = TRUE)
+  archive = ArchiveFSelect$new(search_space = task_to_domain(task), codomain = measures_to_codomain(measures))
+  obj = ObjectiveFSelect$new(task = task, learner = learner, resampling = resampling, measures = measures, archive = archive, store_models = TRUE)
 
   xss = list(
     list("x1" = TRUE, "x2" = FALSE, "x3" = TRUE, "x4" = TRUE),
     list("x1" = FALSE, "x2" = TRUE, "x3" = TRUE, "x4" = TRUE))
 
   z = obj$eval_many(xss)
-  expect_data_table(z, nrows = 2, ncols = 4)
+  expect_data_table(z, nrows = 2, ncols = 6)
 })
 
 test_that("ObjectiveFSelect works with store_models", {
@@ -40,8 +41,9 @@ test_that("ObjectiveFSelect works with store_models", {
   resampling = rsmp("holdout")
   measures = msr("dummy")
 
+   archive = ArchiveFSelect$new(search_space = task_to_domain(task), codomain = measures_to_codomain(measures))
   obj = ObjectiveFSelect$new(task = task, learner = learner,
-    resampling = resampling, measures = measures,
+    resampling = resampling, measures = measures, archive = archive,
     store_models = TRUE)
 
   xss = list(
